@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.17"
+__version__ = "1.0.18"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -30,7 +30,7 @@ class QubellPlatform(object):
 
     def __init__(self, context, auth=None):
         self.organizations = []
-        self.auth = auth | context
+        self.auth = auth or context
         self.user = self.auth.user
         self.password = self.auth.password
         self.tenant = self.auth.tenant
